#
# spec file for package golly
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           golly
Version:        4.2
Release:        2.3
Summary:        Tool for exploring Game of Life and other automata
License:        GPL-2.0-or-later
Group:          Amusements/Toys/Graphics
URL:            https://golly.sourceforge.net/
Source0:        https://downloads.sourceforge.net/%{name}/%{name}-%{version}-src.tar.gz
Source1:        %{name}.desktop
BuildRequires:  SDL2-devel
BuildRequires:  c++_compiler
BuildRequires:  chrpath
BuildRequires:  desktop-file-utils
BuildRequires:  fdupes
BuildRequires:  python3-devel
BuildRequires:  wxGTK3-devel >= 3.1.5
BuildRequires:  zlib-devel
Requires:       %{name}-assets = %{version}
Requires:       python3 >= 3.3

%description
Key features:
- Supports both bounded and unbounded universes.
- Supports various topologies (plane, torus, Klein bottle, etc.).
- Supports multi-state universes (cells can have up to 256 states).
- Includes the QuickLife algorithm.
- Uses the HashLife algorithm to see large patterns evolve at huge time scales.
- Supports many different rules, including Wolfram's 1D rules, WireWorld, Generations, and John von Neumann's 29-state CA.
- Uses the RuleLoader algorithm to load custom rules.
- Reads RLE, macrocell, Life 1.05/1.06, dblife, and MCell files.
- Can also read common graphic formats: BMP, PNG, GIF, TIFF.
- Can extract patterns, scripts and rules from zip files.
- Downloads files from online archives.
- Includes a pattern collection.
- Paste in patterns from the clipboard.
- Unlimited undo/redo.
- Unbounded zooming out for astronomical patterns.
- Auto fit option keeps a generating pattern within view.
- Full screen option (no menu/status/tool/scroll bars).
- Supports multiple layers, including cloned layers.
- HTML-based help with an integrated Life Lexicon.
- Scriptable via Lua or Python.
- User-configurable keyboard shortcuts.

%package assets
Summary:        Assets for %{name}
Group:          Amusements/Toys/Graphics
BuildArch:      noarch

%description assets
This package contains assets for %{name}: Help, rules, patterns and scripts.

%package devel
Summary:        Development files for %{name}
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}

%description devel
This package contains header files and libraries needed to develop applications
that use %{name}.

%prep
%setup -q -n %{name}-%{version}-src
rm -v {Help/Lexicon/modify.pl,docs/Build.html}

%build
%set_build_flags
export GOLLYDIR=%{_datadir}/%{name}
cd gui-wx
%make_build -f makefile-gtk 

%install
install -D -m 0755 bgolly golly -t %{buildroot}%{_bindir}
install -d %{buildroot}%{_datadir}/%{name}
for i in Help Patterns Rules Scripts; do
  find ./$i -type d -exec chmod 755 {} \;
  find ./$i -type f -exec chmod 644 {} \;
  cp -a $i %{buildroot}%{_datadir}/%{name}/$i
done
install -D -m 0644 gui-wx/icons/appicon.xpm %{buildroot}%{_datadir}/pixmaps/%{name}.xpm
install -D -m 0644 %{SOURCE1} -t %{buildroot}%{_datadir}/applications
%fdupes %{buildroot}%{_datadir}
chrpath --delete %{buildroot}%{_bindir}/*golly

%check
desktop-file-validate %{buildroot}%{_datadir}/applications/%{name}.desktop

%files
%license docs/License.html
%doc docs/ReadMe.html docs/ToDo.html
%{_bindir}/*%{name}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/pixmaps/%{name}.xpm

%files assets
%{_datadir}/%{name}
%exclude %{_datadir}/%{name}/Rules/TableGenerators
%exclude %{_datadir}/%{name}/Rules/TreeGenerators

%files devel
%{_datadir}/%{name}/Rules/TableGenerators
%{_datadir}/%{name}/Rules/TreeGenerators

%changelog
* Thu May 18 2023 Jan Engelhardt <jengelh@inai.de>
- Trim unquantified wording from descriptions.
* Thu Apr 27 2023 antoine.belvire@opensuse.org
- Update to version 4.2:
  * Fixed a bug in script commands like g.setpos that accept
    integers as strings.
  * Fixed a number of bugs that could result in an "illegal
    operation while calculating" warning.
  * Performance improvements to Larger than Life NL (Triangular)
    and NB (Checkerboard) rules.
  * Updated Lua to version 5.4.4.
  * Added support for https links when downloading files from
    online archives.
  * New patterns, mostly in OCA (non-Conway's Life) rules, plus
    updates to Life stamp collections.
  * Moved/renamed whiteboard-17c2415-spaceship.rle,
    sierpinski-builder.rle, wolfram22.mc.
  * Reorganized patterns in HashLife folder into subfolders
    "Construction", "Eventful", and "Metacell".
  * Links and dates in many pattern comments updated to standard
    format.
- Changes of versions 4.1, 4.0, 3.4, 3.3, 3.2, 3.1, 3.0, 2.8, 2.7:
  See https://golly.sourceforge.net/Help/changes.html.
- Drop Perl dependencies: Perl scripting has been replaced by Lua
  scripting. golly is built against a patched version of Lua
  included in sources.
- Modify desktop file to run with GDK_BACKEND=x11: Allow to run the
  application built against wxWidgets without EGL support.
- Refreshed spec file.
* Wed Mar 19 2014 avvissu@yandex.ru
- Create sub-package golly-devel-static to provide the static
  library needed for shared builds and to fix compilation on
  Fedora.
* Wed Mar 19 2014 avvissu@yandex.ru
- Add and package desktop file
- Delete golly-zlib.patch
  + Set ZLIB_LDFLAGS in %%{build} instead
- Fix rpmlint error: devel-file-in-non-devel-package
  + Create package golly-devel to package all devel files
* Tue Mar 18 2014 avvissu@yandex.ru
- Update to 2.6 for openSUSE and Fedora:
  * Fixed a nasty bug that could cause Golly to crash when doing a
    paste.
  * Fixed a bug that could cause the paste image to disappear after
    a flip/rotate.
  * Tool bar buttons are no longer disabled when the main window is
    inactive.
  * The save settings in Preferences > Layer are now obeyed by
    scripts. For example, let's assume you've ticked the option to
    be asked to save changes on creating a new pattern. If the
    current layer has changes and you run a script that calls
    new() then you'll get the standard dialog asking if you want
    to save those changes. If you cancel the dialog then the script
    is aborted.
  * To avoid potential data loss, you now get a warning if you save
    a non-starting generation and earlier changes exist. The
    warning can be disabled in Preferences > Layer.
  * Created an online archive for very large patterns.
* Thu Jun  9 2011 prusnak@opensuse.org
- use shared zlib (zlib.patch)
* Thu Jun  2 2011 prusnak@opensuse.org
- updated to 2.2
* Tue Feb 23 2010 prusnak@suse.cz
- created package
